@@ -1,8 +1,8 @@
 writeRscripts = function(reg, cf, ids, chunks.as.arrayjobs, resources.timestamp, disable.mail, delays) {
-  # force loading 'methods' on slave to avoid package trouble there for some jobs
   template = paste(
     "Sys.sleep(%%f)",
     "options(BatchJobs.on.slave = TRUE, BatchJobs.resources.path = '%s')",
+    "library(checkmate)",
     "library(BatchJobs)",
     "res = BatchJobs:::doJob(",
     "\treg = loadRegistry('%s'),",
